#define MAXLINE 132 
#define LIST_SIZE 11

struct pconf{
    char dump_active[MAXLINE];
    char dumpdev[MAXLINE];
    char dumpdir[MAXLINE];
    char dump_level[MAXLINE];
    char dump_flags[MAXLINE];
    char dump_compress[MAXLINE];
    char panic_timeout[MAXLINE];
    char target_host[MAXLINE];
    char target_port[MAXLINE];
    char source_port[MAXLINE];
    char eth_address[MAXLINE];
};

struct pconf * parseconf(char *);
